CREATE OR REPLACE PROCEDURE DAILY_RPT_SNAPSHOT (  i_num_backfill_Days IN INT )
-----------------------------------------------------------------------------
-- File:
--    daily_rpt_snapshot.sql
--
--  DESCRIPTION:
--  Below is a description of each of the inline views and the variables they calculate that
--  either correspond directly to a metric used in the report or are used to construct that
--  metric. Each inline view calculates its metrics at the strategy/queue level.  The following metric prefixes
--  are used (directly or indirectly) in the calculation of metrics used in the following reports:
--      nas_  :  New Alerts Scheduled Report
--      fqfp_ :  Fraud Queue False Positive Report
--
-- INLINE VIEW: SchedAndUnschedTypes
--  METRICS:
--      Scheduled_type_ii - This metric counts all unique alerts that would qualify
--          as Scheduled type ii.  It will be used to calculate the Scheduled metric used in the
--          Fraud Summary Report.
--      nas_Scheduled_type_ii - This metric counts all unique alerts that were created on the snap date
--          and would qualify as Scheduled type ii.  It will be used to calculate the nas_Penetration_Rate metric
--          used in the New Alerts Scheduled report.
--      unscheduled_type_ii - The Unscheduled metric used within the Fraud Summary Report is broken
--          down into three separate categories.  This metric stores type ii values of this metric  Refer to the
--          reporting documentation for details.
--      serviceableReviewed - Alerts that have been statused but at the end of the time period
--          are again serviceable contribute to the ScheduledReviewed metric, which is used in the Fraud Summary
--          Report.
--      nas_serviceableReviewed - Alerts created on the snap date that have been statused
--          but at the end of the time period are again serviceable contribute to the nas_Penetration_Rate metric
--          used in the New Alerts Scheduled report.
--      Unscheduled_types_i_and_iii - This metric counts all unique alerts that satisfy
--          Unscheduled type i and Unscheduled type iii for the given day.
--      Actioned - This is the count of unique alerts that were actioned in the given queue
--          for the given day
--      nas_Actioned - This is the count of unique alerts that were created on the snap date
--          and actioned in the given queue for the given day
--      verifiedActivity - Number of unique alerts within a given queue that had a *final status* of
--          Verified Activity by the end of the given day.
--      nas_verifiedActivity - Number of unique alerts within a given queue that had a *final status* of
--          Verified Activity by the end of the given day that were also created that day.
--      confirmedFraud - Number of unique alerts within a given queue that had a *final status* of
--          Confirmed Fraud by the end of the given day.
--      nas_confirmedFraud - Number of unique alerts within a given queue that had a *final status* of
--          Confirmed Fraud by the end of the given day that were also created that day.
--      prevented - The amount of remaining credit in a given queue on accounts that had a
--          *final status* of Confirmed Fraud by the end of the given day.
--      nas_prevented - The amount of remaining credit in a given queue on accounts that had alerts created
--          during the snap date and had a *final status* of Confirmed Fraud by the end of the given day.
--      fqfp_verifiedActivity_inb_cnt - Number of unique alerts within a given queue that had a *final status* of
--          Verified Activity by the end of the given day that were also statused in Inbound mode.
--      fqfp_confirmedFraud_inb_cnt - Number of unique alerts within a given queue that had a *final status* of
--          Confirmed Fraud by the end of the given day that were also statused in Inbound mode.
--      fqfp_verifiedActivity_out_cnt - Number of unique alerts within a given queue that had a *final status* of
--          Verified Activity by the end of the given day that were also statused in Outbound mode.
--      fqfp_confirmedFraud_out_cnt - Number of unique alerts within a given queue that had a *final status* of
--          Confirmed Fraud by the end of the given day that were also statused in Outbound mode.
--  ALGORITHM:
--      We essentially want to surface every alert that was statused and know the queue in which it
--      was statused. However, in order to know how to categorize them properly, we have to
--      know the status of the alert at the end of the given day. It's quite possible that
--      at the end of the given day, an alert will reside in a queue that is different from
--      the one in which it was statused. It's also possible for the same unique alert to be
--      statused in multiple different queues during the given day. The SQL for this
--      inline view joins the two dynamically created tables (each containing their own dynamically
--      created tables): (1) dynamic table "aa" stores the last action taken on a unique alert
--      during the given day and (2) dynamic table "latest" finds, for each unique alert that was
--      statused within a given queue during the day, the latest action on the alert
--       while it resided within that queue.  In order to determine whether or not the alert was
--       serviceable at the time it was statused, we need to grab the next_service_timestamp value
--       on the action record just prior to the alert status.
--
-- INLINE VIEW: serviceableAlerts
--  METRICS:
--      serviceableAlertsCnt - The number of serviceable alerts at the end of the given day, broken
--          out by queue.
--      nas_serviceableAlertsCnt - The number of alerts created on the snap date that were serviceable
--          at the end of the day, broken out by queue.
--  ALGORITHM:
--      Extract the last action for each unique alert before the end of the given day. For each
--      alert, determine which are serviceable and which are new from these records. Each alert that is
--      categorized as new/scheduled will contribute to the newAlertsCnt/serviceableAlertsCnt metric for
--      the queue that the alert was in at the end of the given day.
--
-- INLINE VIEW: unresolvedActions
--  METRICS:
--      newAlertsCnt - The number of alerts in each queue at the end of the given day that were
--          were created that day.
--      connectCnt - The number of times analysts statused alerts in a given queue during the given
--          day
--      nas_analystActionCount - The number of times analysts statused new alerts (created on the snap date)
--          in a given queue during the given day
--      totalTimeSec - The total number of seconds taken by analysts statusing alerts during the given day,
--          broken out by queue.
--      nas_totalTimeSec - The total number of seconds taken by analysts statusing new alerts (created on the
--          snap date) during the given day that were created on the snap date, broken out by queue.
--      rescheduleCnt - The number of times analysts statused alerts as Reschedule in a given queue
--          during the given day
--      nas_rescheduleCnt - The number of times analysts statused new alerts (created on the snap date)
--          as Reschedule in a given queue during the given day
--      skipCnt - The number of times analysts statused alerts as Skip in a given queue
--          during the given day
--      nas_skipCnt - The number of times analysts statused new alerts (created on the snap date)
--          as Skip in a given queue during the given day
--      pendCnt - The number of times analysts statused alerts as Pend in a given queue
--          during the given day
--      nas_pendCnt - The number of times analysts statused new alerts (created on the snap date) as
--          Pend in a given queue during the given day
--      pendBlockCnt - The number of times analysts statused alerts as Pend with block in a given queue
--          during the given day
--      nas_pendBlockCnt - The number of times analysts statused new alerts (created on the snap date)
--          as Pend with block in a given queue during the given day
--      reRouteCnt - The number of times analysts Rerouted alerts *into* a given queue
--          during the given day
--      nas_reRouteCnt - The number of times analysts Rerouted new alerts (created on the snap date)
--          *into* a given queue during the given day
--  ALGORITHM:
--      Tally all the "unresolved" alert statuses and the time taken to perform the statuses during
--      the given day, breaking the values out by the queue in which they occurred.
--
-- Called By:
--    Cron job that is scheduled to run intermittently throughout the day (most likely hourly).
--
-- Calls:
--
--
-- Notes:
--    The proc is built so that it can backfill any days that are missed
--    due to downtime. A default of 30 days can be backfilled.
--  -- 2007-02-24 Update --
--  When multiple executions of the proc
--  are done on the same day, the ITERATION_NUMBER will be incremented and the data resummarized
--  for the day.
--
-- Usage:
--
--
-- History:
--     Date          User                Notes
--     2012/07/23    leushe                 Ported from DB2
--     2014/06/19    leushe                 Fixed DATE issue, so DATE is a DATE not a timestamp
--
------------------------------------------------------------------------

IS

     l_last_date DATE;
     l_current_server_date DATE;
     l_current_gmt_timestamp TIMESTAMP;

     l_snap_date DATE;
     l_gmt_offset_hour INTEGER;
     l_gmt_offset_minute INTEGER;
     l_row_count INTEGER;
     l_iteration_nbr INTEGER;
     l_num_backfill_days INTEGER;

BEGIN
    -- Step 1. set local variables
    -- Use a default value of 30 for the number of backfill days if it isn't passed into the proc
    if i_num_backfill_Days is null then
      l_num_backfill_days:=30;
    else
        l_num_backfill_days:=i_num_backfill_Days;
    end if;
    -- DB2 stores timezones in the DECIMAL(6,0) format where the values are represented as HHMMSS
    --  These two mathematical transformations will yield integer values for the number of hours off GMT
    --  and the number of minutes off GMT.
    l_gmt_offset_hour := floor(cast(replace(DBTIMEZONE,':','.') as integer)/10000);
    l_gmt_offset_minute := floor(mod(cast(replace(DBTIMEZONE,':','.') as INTEGER),10000)/100);


    --  Set values for current server date and current GMT timestamp.
    l_current_server_date := current_date;
    l_current_gmt_timestamp := SYS_EXTRACT_UTC(CURRENT_TIMESTAMP);

    --
    -- Determine the last date that was populated within FCM_DAILY_SNAPSHOT.
    --  This will establish the baseline for every subselect in the big insert statement
    --
    select count(*) into l_row_count from FCM_DAILY_SNAPSHOT;
    IF ( l_row_count = 0 ) THEN
--SELECT time1,
--           time2,
--           substr((time2-time1),instr((time2-time1),' ')+7,2)                 seconds,
--           substr((time2-time1),instr((time2-time1),' ')+4,2)                 minutes,
--           substr((time2-time1),instr((time2-time1),' ')+1,2)                 hours,
--           trunc(to_number(substr((time2-time1),1,instr(time2-time1,' '))))   days,
--           trunc(to_number(substr((time2-time1),1,instr(time2-time1,' ')))/7) weeks
--     FROM date_table

         l_last_date := l_current_server_date - ( l_num_backfill_Days + 1 ) ;
         l_iteration_nbr := -1;
    ELSE
        select max(coalesce(snap_date, l_current_server_date)) into l_last_date from FCM_DAILY_SNAPSHOT;
        select max(coalesce(iteration_number,99)) into l_iteration_nbr from FCM_DAILY_SNAPSHOT where snap_date = l_last_date;
    END IF;

     l_snap_date := trunc(l_last_date);
     l_iteration_nbr := l_iteration_nbr + 1;

    WHILE ( l_snap_date <= l_current_server_date) LOOP

-- S0553598 LEUSHE
--      IF ( v_sqlstate = '00000' ) THEN

            INSERT INTO fcm_daily_snapshot
            (snap_date, iteration_number, loader_gmt_timestamp, multi_org_id, strategy_id, queue_id,
                multi_org_name, strategy_name, queue_name, alert_type, alert_type_name,
                total_alert_count, scheduled_alert_count, ac_carryover_alert_count, new_alert_count,
                unschd_alert_count, actioned_alert_count, schd_actioned_alert_count, alert_penetration_rate,
                unschd_actioned_alert_count, analyst_action_count, resolved_alert_count, resolved_alert_rate,
                skip_count, reroute_count, reschd_count, pend_count, pend_block_count,
                verified_ok_count, confirmed_fraud_count, fp_ratio, saved_amount, total_seconds_worked,
                fqfp_verifiedActivity_out_cnt, fqfp_verifiedActivity_inb_cnt, fqfp_confirmedFraud_out_cnt,
                fqfp_confirmedFraud_inb_cnt, 
                  fqfp_out_fpRatio,
                  fqfp_inb_fpRatio, 
                nas_analyst_action_count, nas_total_seconds_worked,
                nas_skip_count, nas_reschd_count, nas_reroute_count, nas_pend_count, nas_pend_block_count, nas_verified_ok_count,
                nas_confirmed_fraud_count, nas_resolved_alert_count, nas_actioned_alert_count, nas_resolved_alert_rate,
                nas_saved_amount, nas_fp_ratio, nas_penetration_rate
            )
            WITH
                SchedAndUnschedTypes as
                (
                    select latest.business_unit_id, latest.multi_org_id, latest.strategy_id, latest.queue_id, latest.alert_type,
                        sum(
                            case
                                when latest.strategy_type_code = 'OUT' and
                                    latest.statusWithinAWH = 1 and latest.priorToStatus_NST <= latest.latestStatusTimestamp and
                                    (((aa.lastAlertAction_NST - 10 ) +  (l_gmt_offset_hour/24) + (l_gmt_offset_minute/1440)) >
                                    (to_timestamp(to_char((l_snap_date - 10), 'YYYY-MM-DD')  ||' '|| rtrim(to_char(qub_time,'HH24.MI.SS')),'YYYY-MM-DD HH24.MI.SS') + (1/24))
                                    or aa.finalAlertStatus <> 'ACTIVE')
                                    then 1
                                else 0
                            end
                        ) as Scheduled_type_ii,
                        sum(
                            case
                                when latest.strategy_type_code = 'OUT' and
                                    latest.statusWithinAWH = 1 and latest.priorToStatus_NST <= latest.latestStatusTimestamp and
                                    (((aa.lastAlertAction_NST - 10 ) + (l_gmt_offset_hour/24) + (l_gmt_offset_minute/1440)) > (to_timestamp(to_char((l_snap_date - 10), 'YYYY-MM-DD')  ||' '|| rtrim(to_char(qub_time,'HH24.MI.SS')),'YYYY-MM-DD HH24.MI.SS') + (1/24))
                                    or aa.finalAlertStatus <> 'ACTIVE') and
                                    trunc(to_date(latest.create_timestamp + (l_gmt_offset_hour/24) + (l_gmt_offset_minute/1440))) = l_snap_date
                                    then 1
                                else 0
                            end
                        ) as nas_Scheduled_type_ii,
                        sum(
                            case
                                when latest.strategy_type_code = 'OUT' and
                                    ((latest.priorToStatus_NST > latest.latestStatusTimestamp)
                                        or
                                        latest.statusWithinAWH = 0)
                                    then 1
                                else 0
                            end
                        ) as unscheduled_type_ii,
                        sum(
                            case
                                when latest.strategy_type_code = 'OUT' and latest.statusWithinAWH = 1 and latest.priorToStatus_NST <= latest.latestStatusTimestamp and
                                    (((aa.lastAlertAction_NST - 10 ) + (l_gmt_offset_hour/24) + (l_gmt_offset_minute/1440)) <= (to_timestamp(to_char((l_snap_date - 10), 'YYYY-MM-DD')  ||' '|| rtrim(to_char(qub_time,'HH24.MI.SS')),'YYYY-MM-DD HH24.MI.SS') + (1/24))
                                    and aa.finalAlertStatus = 'ACTIVE')
                                    then 1
                                else 0
                            end
                        ) as serviceableReviewed,
                        sum(
                            case
                                when latest.strategy_type_code = 'OUT' and (latest.statusWithinAWH = 0 or latest.priorToStatus_NST > latest.latestStatusTimestamp) and
                                    (((aa.lastAlertAction_NST - 10 ) + (l_gmt_offset_hour/24) + (l_gmt_offset_minute/1440) ) <= (to_timestamp(to_char((l_snap_date - 10), 'YYYY-MM-DD')  ||' '|| rtrim(to_char(qub_time,'HH24.MI.SS')),'YYYY-MM-DD HH24.MI.SS') + (1/24))  and aa.finalAlertStatus = 'ACTIVE')
                                    then 1
                                else 0
                            end
                        ) as serviceableUnschedReviewed,
                        sum(
                            case
                                when latest.strategy_type_code = 'OUT' and latest.statusWithinAWH = 1 and
                                    (((aa.lastAlertAction_NST - 10 ) + (l_gmt_offset_hour/24) + (l_gmt_offset_minute/1440) ) <= (to_timestamp(to_char((l_snap_date - 10), 'YYYY-MM-DD')  ||' '|| rtrim(to_char(qub_time,'HH24.MI.SS')),'YYYY-MM-DD HH24.MI.SS') + (1/24))

                                    and aa.finalAlertStatus = 'ACTIVE') and
                                    trunc(to_date(latest.create_timestamp + (l_gmt_offset_hour/24) + (l_gmt_offset_minute/1440) )) = l_snap_date
                                    then 1
                                else 0
                            end
                        ) as nas_serviceableReviewed,
                        sum(
                            case
                                when latest.strategy_type_code in ('EML','LTR','SMS')
                                    then 1
                                else 0
                            end
                        ) as Unscheduled_types_i_and_iii,
                        sum(
                            case
                                when aa.max_alert_action_id = latest.latestStatusActionID and
                                    aa.result_id = 6
                                    then 1
                                else 0
                            end
                        ) as verifiedActivity,
                        sum(
                            case
                                when aa.max_alert_action_id = latest.latestStatusActionID and
                                    aa.result_id = 7
                                    then 1
                                else 0
                            end
                        ) as confirmedFraud,
                        sum(
                            case
                                when aa.max_alert_action_id = latest.latestStatusActionID and
                                   trunc( to_date(latest.create_timestamp + (l_gmt_offset_hour/24) + (l_gmt_offset_minute/1440) )) = l_snap_date and
                                    aa.result_id = 6 and latest.strategy_type_code = 'OUT'
                                    then 1
                                else 0
                            end
                        ) as nas_verifiedActivity,
                        sum(
                            case
                                when aa.max_alert_action_id = latest.latestStatusActionID and
                                   trunc( to_date(latest.create_timestamp + (l_gmt_offset_hour/24) + (l_gmt_offset_minute/1440) )) = l_snap_date and
                                    aa.result_id = 7 and latest.strategy_type_code = 'OUT'
                                    then 1
                                else 0
                            end
                        ) as nas_confirmedFraud,
                        sum(
                            case
                                when aa.max_alert_action_id = latest.latestStatusActionID and
                                    aa.result_id = 6 and service_method_code = 'INB'
                                    then 1
                                else 0
                            end
                        ) as fqfp_verifiedActivity_inb_cnt,
                        sum(
                            case
                                when aa.max_alert_action_id = latest.latestStatusActionID and
                                    aa.result_id = 7 and service_method_code = 'INB'
                                    then 1
                                else 0
                            end
                        ) as fqfp_confirmedFraud_inb_cnt,
                        sum(
                            case
                                when aa.max_alert_action_id = latest.latestStatusActionID and
                                    aa.result_id = 6 and service_method_code = 'OUT'
                                    then 1
                                else 0
                            end
                        ) as fqfp_verifiedActivity_out_cnt,
                        sum(
                            case
                                when aa.max_alert_action_id = latest.latestStatusActionID and
                                    aa.result_id = 7 and service_method_code = 'OUT'
                                    then 1
                                else 0
                            end
                        ) as fqfp_confirmedFraud_out_cnt,
                        sum(
                            case
                                when aa.max_alert_action_id = latest.latestStatusActionID and
                                    aa.result_id = 7 and aa.fraud_type_code = 'FA'
                                    then 1
                                else 0
                            end
                        ) as fqfp_facf_cnt,
                        sum(
                            case
                                when aa.max_alert_action_id = latest.latestStatusActionID and
                                    aa.result_id = 7 and aa.fraud_type_code = 'FA' and service_method_code = 'OUT'
                                    then 1
                                else 0
                            end
                        ) as fqfp_facf_out_cnt,
                        sum(
                            case
                                when aa.max_alert_action_id = latest.latestStatusActionID and
                                    aa.result_id = 7 and aa.fraud_type_code = 'FA' and service_method_code = 'INB'
                                    then 1
                                else 0
                            end
                        ) as fqfp_facf_inb_cnt,
                        sum(
                            case
                                when aa.max_alert_action_id = latest.latestStatusActionID and
                                    aa.result_id = 7 and aa.fraud_type_code = 'CO'
                                    then 1
                                else 0
                            end
                        ) as fqfp_cocf_cnt,
                        sum(
                            case
                                when aa.max_alert_action_id = latest.latestStatusActionID and
                                    aa.result_id = 7 and aa.fraud_type_code = 'CO' and service_method_code = 'OUT'
                                    then 1
                                else 0
                            end
                        ) as fqfp_cocf_out_cnt,
                        sum(
                            case
                                when aa.max_alert_action_id = latest.latestStatusActionID and
                                    aa.result_id = 7 and aa.fraud_type_code = 'CO' and service_method_code = 'INB'
                                    then 1
                                else 0
                            end
                        ) as fqfp_cocf_inb_cnt,
                        sum(
                            case
                                when aa.max_alert_action_id = latest.latestStatusActionID and
                                    aa.result_id = 7 and aa.fraud_type_code = 'CS'
                                    then 1
                                else 0
                            end
                        ) as fqfp_cscf_cnt,
                        sum(
                            case
                                when aa.max_alert_action_id = latest.latestStatusActionID and
                                    aa.result_id = 7 and aa.fraud_type_code = 'CS' and service_method_code = 'OUT'
                                    then 1
                                else 0
                            end
                        ) as fqfp_cscf_out_cnt,
                        sum(
                            case
                                when aa.max_alert_action_id = latest.latestStatusActionID and
                                    aa.result_id = 7 and aa.fraud_type_code = 'CS' and service_method_code = 'INB'
                                    then 1
                                else 0
                            end
                        ) as fqfp_cscf_inb_cnt,
                        sum(
                            case
                                when aa.max_alert_action_id = latest.latestStatusActionID and
                                    aa.result_id = 7 and aa.fraud_type_code = 'BO'
                                    then 1
                                else 0
                            end
                        ) as fqfp_bocf_cnt,
                        sum(
                            case
                                when aa.max_alert_action_id = latest.latestStatusActionID and
                                    aa.result_id = 7 and aa.fraud_type_code = 'BO' and service_method_code = 'OUT'
                                    then 1
                                else 0
                            end
                        ) as fqfp_bocf_out_cnt,
                        sum(
                            case
                                when aa.max_alert_action_id = latest.latestStatusActionID and
                                    aa.result_id = 7 and aa.fraud_type_code = 'BO' and service_method_code = 'INB'
                                    then 1
                                else 0
                            end
                        ) as fqfp_bocf_inb_cnt,
                        sum(
                            case
                                when aa.max_alert_action_id = latest.latestStatusActionID and
                                    aa.result_id = 7 and aa.fraud_type_code = 'NR'
                                    then 1
                                else 0
                            end
                        ) as fqfp_nrcf_cnt,
                        sum(
                            case
                                when aa.max_alert_action_id = latest.latestStatusActionID and
                                    aa.result_id = 7 and aa.fraud_type_code = 'NR' and service_method_code = 'OUT'
                                    then 1
                                else 0
                            end
                        ) as fqfp_nrcf_out_cnt,
                        sum(
                            case
                                when aa.max_alert_action_id = latest.latestStatusActionID and
                                    aa.result_id = 7 and aa.fraud_type_code = 'NR' and service_method_code = 'INB'
                                    then 1
                                else 0
                            end
                        ) as fqfp_nrcf_inb_cnt,
                        sum(
                            case
                                when aa.max_alert_action_id = latest.latestStatusActionID and
                                    aa.result_id = 7 and aa.fraud_type_code = 'TK'
                                    then 1
                                else 0
                            end
                        ) as fqfp_tkcf_cnt,
                        sum(
                            case
                                when aa.max_alert_action_id = latest.latestStatusActionID and
                                    aa.result_id = 7 and aa.fraud_type_code = 'TK' and service_method_code = 'OUT'
                                    then 1
                                else 0
                            end
                        ) as fqfp_tkcf_out_cnt,
                        sum(
                            case
                                when aa.max_alert_action_id = latest.latestStatusActionID and
                                    aa.result_id = 7 and aa.fraud_type_code = 'TK' and service_method_code = 'INB'
                                    then 1
                                else 0
                            end
                        ) as fqfp_tkcf_inb_cnt,
                        sum(
                            case
                                when aa.max_alert_action_id = latest.latestStatusActionID and
                                    aa.result_id = 7 and aa.fraud_type_code = 'CNP'
                                    then 1
                                else 0
                            end
                        ) as fqfp_cnpcf_cnt,
                        sum(
                            case
                                when aa.max_alert_action_id = latest.latestStatusActionID and
                                    aa.result_id = 7 and aa.fraud_type_code = 'CNP' and service_method_code = 'OUT'
                                    then 1
                                else 0
                            end
                        ) as fqfp_cnpcf_out_cnt,
                        sum(
                            case
                                when aa.max_alert_action_id = latest.latestStatusActionID and
                                    aa.result_id = 7 and aa.fraud_type_code = 'CNP' and service_method_code = 'INB'
                                    then 1
                                else 0
                            end
                        ) as fqfp_cnpcf_inb_cnt,
                        sum(
                            case
                                when aa.max_alert_action_id = latest.latestStatusActionID and
                                    aa.result_id = 7 and aa.fraud_type_code = 'LO'
                                    then 1
                                else 0
                            end
                        ) as fqfp_locf_cnt,
                        sum(
                            case
                                when aa.max_alert_action_id = latest.latestStatusActionID and
                                    aa.result_id = 7 and aa.fraud_type_code = 'LO' and service_method_code = 'OUT'
                                    then 1
                                else 0
                            end
                        ) as fqfp_locf_out_cnt,
                        sum(
                            case
                                when aa.max_alert_action_id = latest.latestStatusActionID and
                                    aa.result_id = 7 and aa.fraud_type_code = 'LO' and service_method_code = 'INB'
                                    then 1
                                else 0
                            end
                        ) as fqfp_locf_inb_cnt,
                        sum(
                            case
                                when aa.max_alert_action_id = latest.latestStatusActionID and
                                    aa.result_id = 7 and aa.fraud_type_code = 'ST'
                                    then 1
                                else 0
                            end
                        ) as fqfp_stcf_cnt,
                        sum(
                            case
                                when aa.max_alert_action_id = latest.latestStatusActionID and
                                    aa.result_id = 7 and aa.fraud_type_code = 'ST' and service_method_code = 'OUT'
                                    then 1
                                else 0
                            end
                        ) as fqfp_stcf_out_cnt,
                        sum(
                            case
                                when aa.max_alert_action_id = latest.latestStatusActionID and
                                    aa.result_id = 7 and aa.fraud_type_code = 'ST' and service_method_code = 'INB'
                                    then 1
                                else 0
                            end
                        ) as fqfp_stcf_inb_cnt,
                        sum(
                            case
                                when aa.max_alert_action_id = latest.latestStatusActionID and
                                    aa.result_id = 7
                                    then aa.open_to_buy_amt
                                else 0
                            end
                        ) as prevented,
                        sum(
                            case
                                when aa.max_alert_action_id = latest.latestStatusActionID and
                                   trunc( to_date(latest.create_timestamp + (l_gmt_offset_hour/24) + (l_gmt_offset_minute/1440) )) = l_snap_date and
                                    aa.result_id = 7 and latest.strategy_type_code = 'OUT'
                                    then aa.open_to_buy_amt
                                else 0
                            end
                        ) as nas_prevented,
                        sum(
                            case
                                when trunc(to_date(latest.create_timestamp + (l_gmt_offset_hour/24) + (l_gmt_offset_minute/1440) )) = l_snap_date and
                                    latest.strategy_type_code = 'OUT'
                                    then 1
                                else 0
                            end
                        ) as nas_Actioned,
                        count(*) as Actioned
                    from
                        (
                            select fcmaa.alert_id, fcmaa.create_timestamp, latestAlertActionRecords.max_alert_action_id,
                                fcmaa.next_service_timestamp as lastAlertAction_NST, fcmaa.alert_status as finalAlertStatus,
                                fcmaa.result_id, fcmaa.open_to_buy_amt, fcmaa.fraud_type_code, fcmaa.service_method_code
                            from fcm_alert_action fcmaa
                            inner join
                            (
                                select alert_id, create_timestamp, max(alert_action_id) as max_alert_action_id
                                from fcm_alert_action
                                where
                                    trunc(to_date(action_timestamp + (l_gmt_offset_hour/24) + (l_gmt_offset_minute/1440) )) = l_snap_date and action_type = 'ANALYST ACTION' and result_id > 0
                                group by alert_id, create_timestamp
                            )  latestAlertActionRecords
                            on fcmaa.alert_id = latestAlertActionRecords.alert_id and
                                fcmaa.create_timestamp = latestAlertActionRecords.create_timestamp and
                                fcmaa.alert_action_id = latestAlertActionRecords.max_alert_action_id
                        ) aa inner join
                        (
                            select statusedAlerts.alert_id, statusedAlerts.create_timestamp, statusedAlerts.queue_id, statusedAlerts.qub_time,
                                statusedAlerts.latestStatusTimestamp, statusedAlerts.latestStatusActionID, statusedAlerts.statusWithinAWH,
                                faa.next_service_timestamp as priorToStatus_NST,
                                faa.alert_origin, s.business_unit_id, faa.multi_org_id, faa.alert_type, s.strategy_id, s.strategy_type_code
                            from fcm_alert_action faa inner join
                                (
                                    select aa.alert_id, aa.create_timestamp, latestStatus.queue_id, latestStatus.qub_time, latestStatus.latestStatusActionID, latestStatus.latestStatusTimestamp,
                                         case
                                            when (EXTRACT(HOUR FROM latestStatus.latestStatusTimestamp) + (l_gmt_offset_hour) + (l_gmt_offset_minute/60))  between queue_call_lower_bound and queue_call_upper_bound
                                                then 1
                                            else 0
                                         end as statusWithinAWH,
                                         max(alert_action_id) as secondLatestStatusActionID
                                    from fcm_alert_action aa inner join
                                        (
                                            select aa.alert_id, aa.create_timestamp, aa.queue_id, q1.queue_call_lower_bound, q1.queue_call_upper_bound, to_timestamp(rtrim(to_char(q1.queue_call_upper_bound))||'.00.00','HH24.MI.SS') as qub_time, max(action_timestamp) as latestStatusTimestamp, max(alert_action_id) as latestStatusActionID
                                            from fcm_alert_action aa inner join fcm_queue q1 on q1.queue_id = aa.queue_id
                                            where
                                               trunc( to_date(action_timestamp + (l_gmt_offset_hour/24) + (l_gmt_offset_minute/1440)) ) = l_snap_date and
                                                alert_status = 'ACTIVE' and
                                                action_type = 'ANALYST ACTION' and
                                                result_id > 0
                                            group by aa.alert_id, aa.create_timestamp, aa.queue_id, queue_call_lower_bound, queue_call_upper_bound, to_timestamp(rtrim(to_char(q1.queue_call_upper_bound))||'.00.00','HH24.MI.SS')
                                        ) latestStatus
                                        on aa.alert_id = latestStatus.alert_id and aa.create_timestamp = latestStatus.create_timestamp and alert_action_id < latestStatus.latestStatusActionID
                                    group by aa.alert_id, aa.create_timestamp, latestStatus.queue_id, queue_call_lower_bound, queue_call_upper_bound, qub_time, latestStatus.latestStatusActionID, latestStatus.latestStatusTimestamp
                                ) statusedAlerts
                                on faa.alert_id = statusedAlerts.alert_id and faa.create_timestamp = statusedAlerts.create_timestamp and faa.alert_action_id = statusedAlerts.secondLatestStatusActionID
                                inner join
                                    fcm_queue q on statusedAlerts.queue_id = q.queue_id and q.logical_del_ind = '0'
                                inner join
                                    fcm_strategy s on q.strategy_id = s.strategy_id and s.logical_del_ind = '0'
                        ) latest
                        on
                            aa.alert_id = latest.alert_id and
                            aa.create_timestamp = latest.create_timestamp
                    group by latest.business_unit_id, latest.multi_org_id, latest.strategy_id, latest.queue_id, latest.alert_type
                ),
                serviceableAlerts as
                (
                    select s.business_unit_id, aa.multi_org_id, s.strategy_id, q.queue_id, aa.alert_type,
                        sum(
                            case
                                when s.strategy_type_code = 'OUT' and (aa.next_service_timestamp - 10  + (l_gmt_offset_hour/24) + (l_gmt_offset_minute/1440) ) <=
                                (to_timestamp((to_char((l_snap_date - 10), 'YYYY-MM-DD') ||' '|| rtrim(to_char(q.queue_call_upper_bound))||'.00.00'),'YYYY-MM-DD HH24.MI.SS') + (1/24))
                                 and alert_status = 'ACTIVE'
                                    then 1
                                else 0
                            end
                        ) as serviceableAlertsCnt,
                        sum(
                            case
                                when s.strategy_type_code = 'OUT' and
                                    ((aa.next_service_timestamp - 10)  + (l_gmt_offset_hour/24) + (l_gmt_offset_minute/1440) ) <= (to_timestamp((to_char((l_snap_date - 10), 'YYYY-MM-DD') ||' '|| rtrim(to_char(q.queue_call_upper_bound))||'.00.00'),'YYYY-MM-DD HH24.MI.SS') + (1/24))
                                    and alert_status = 'ACTIVE'
                                    and trunc(to_date(aa.create_timestamp + (l_gmt_offset_hour/24) + (l_gmt_offset_minute/1440) )) = l_snap_date
                                    then 1
                                else 0
                            end
                        ) as nas_serviceableAlertsCnt
                    from fcm_alert_action aa
                        inner join
                        (
                        select alert_id, create_timestamp, max(alert_action_id) as maxAlertActionID
                        from fcm_alert_action aa
                        where
                            trunc(to_date(action_timestamp + (l_gmt_offset_hour/24) + (l_gmt_offset_minute/1440) )) <= l_snap_date
                        group by alert_id, create_timestamp
                        )  latestAlertActionRecords
                        on aa.alert_id = latestAlertActionRecords.alert_id and
                            aa.create_timestamp = latestAlertActionRecords.create_timestamp and
                            aa.alert_action_id = latestAlertActionRecords.maxAlertActionID
                        inner join fcm_queue q on aa.queue_id = q.queue_id and q.logical_del_ind = '0'
                        inner join fcm_strategy s on q.strategy_id = s.strategy_id and s.logical_del_ind = '0'
                    group by s.business_unit_id, aa.multi_org_id, s.strategy_id, q.queue_id, aa.alert_type
                ),
                unresolvedActions as
                (
                    select
                        s.business_unit_id,
                        a.multi_org_id,
                        s.strategy_id,
                        q.queue_id,
                        a.alert_type,
                        sum(
                            case
                                when a.action_type in ('ALERTINIT','INITCLOSED') and a.alert_status in ('ACTIVE','CHECKOUT')
                                    then 1
                                else 0
                            end
                        ) as newAlertsCnt,
                        sum(
                            case
                                when a.result_id > 0 and
                                    a.alert_status = 'ACTIVE' and
                                    a.action_type = 'ANALYST ACTION'
                                then 1
                                else 0
                            end
                        ) as connectCnt,
                        sum(
                            case
                                when a.result_id > 0 and
                                    a.alert_status = 'ACTIVE' and
                                    a.action_type = 'ANALYST ACTION' and
                                    trunc(to_date(a.create_timestamp + (l_gmt_offset_hour/24) + (l_gmt_offset_minute/1440)) ) = l_snap_date and
                                    s.strategy_type_code = 'OUT'
                                then 1
                                else 0
                            end
                        ) as nas_analystActionCount,
                        sum(
                            case
                                when a.result_id > 0 and
                                    a.alert_status = 'ACTIVE' and
                                    a.action_type = 'ANALYST ACTION'
                                then
                                TO_NUMBER(substr((a.ACTION_TIMESTAMP-a.User_SERVICE_TIMESTAMP),instr((a.ACTION_TIMESTAMP-a.User_SERVICE_TIMESTAMP),' ')+7,2))
                                --sysfun.timestampdiff(2,char(a.ACTION_TIMESTAMP - a.User_SERVICE_TIMESTAMP))
                                else 0
                            end
                        ) as totalTimeSec,
                        sum(
                            case
                                when a.result_id > 0 and
                                    a.alert_status = 'ACTIVE' and
                                    a.action_type = 'ANALYST ACTION' and
                                    trunc(to_date(a.create_timestamp + (l_gmt_offset_hour/24) + (l_gmt_offset_minute/1440) )) = l_snap_date and
                                    s.strategy_type_code = 'OUT'
                                then
                                TO_NUMBER(substr((a.ACTION_TIMESTAMP-a.User_SERVICE_TIMESTAMP),instr((a.ACTION_TIMESTAMP-a.User_SERVICE_TIMESTAMP),' ')+7,2))
                                --sysfun.timestampdiff(2,char(a.ACTION_TIMESTAMP - a.User_SERVICE_TIMESTAMP))
                                else 0
                            end
                        ) as nas_totalTimeSec,
                        sum(
                            case
                                when a.result_id = 2 and
                                    a.alert_status = 'ACTIVE' and
                                    a.action_type = 'ANALYST ACTION'
                                then 1
                                else 0
                            end
                        ) as rescheduleCnt,
                        sum(
                            case
                                when a.result_id = 2 and
                                    a.alert_status = 'ACTIVE' and
                                    a.action_type = 'ANALYST ACTION' and
                                   trunc( to_date(a.create_timestamp + (l_gmt_offset_hour/24) + (l_gmt_offset_minute/1440)) ) = l_snap_date and
                                    s.strategy_type_code = 'OUT'
                                then 1
                                else 0
                            end
                        ) as nas_rescheduleCnt,
                        sum(
                            case
                                when a.result_id = 1 and
                                    a.alert_status = 'ACTIVE' and
                                    a.action_type = 'ANALYST ACTION'
                                then 1
                                else 0
                            end
                        ) as skipCnt,
                        sum(
                            case
                                when a.result_id = 1 and
                                    a.alert_status = 'ACTIVE' and
                                    a.action_type = 'ANALYST ACTION' and
                                    trunc(to_date(a.create_timestamp + (l_gmt_offset_hour/24) + (l_gmt_offset_minute/1440) )) = l_snap_date and
                                    s.strategy_type_code = 'OUT'
                                then 1
                                else 0
                            end
                        ) as nas_skipCnt,
                        sum(
                            case
                                when a.result_id = 3 and
                                    a.alert_status = 'ACTIVE' and
                                    a.action_type = 'ANALYST ACTION'
                                then 1
                                else 0
                            end
                        ) as pendCnt,
                        sum(
                            case
                                when a.result_id = 3 and
                                    a.action_type = 'ANALYST ACTION' and
                                    a.alert_status = 'ACTIVE' and
                                    trunc(to_date(a.create_timestamp + (l_gmt_offset_hour/24) + (l_gmt_offset_minute/1440)) ) = l_snap_date and
                                    s.strategy_type_code = 'OUT'
                                then 1
                                else 0
                            end
                        ) as nas_pendCnt,
                        sum(
                            case
                                when a.result_id = 4 and
                                    a.action_type = 'ANALYST ACTION' and
                                    a.alert_status = 'ACTIVE'
                                then 1
                                else 0
                            end
                        ) as pendBlockCnt,
                        sum(
                            case
                                when a.result_id = 4 and
                                    a.action_type = 'ANALYST ACTION' and
                                    a.alert_status = 'ACTIVE' and
                                    trunc(to_Date(a.create_timestamp + (l_gmt_offset_hour/24) + (l_gmt_offset_minute/1440) )) = l_snap_date and
                                    s.strategy_type_code = 'OUT'
                                then 1
                                else 0
                            end
                        ) as nas_pendBlockCnt,
                        sum(
                            case
                                when a.result_id = 5 and
                                    a.action_type = 'ANALYST ACTION' and
                                    a.alert_status = 'ACTIVE'
                                then 1
                                else 0
                            end
                        ) as reRouteCnt,
                        sum(
                            case
                                when a.result_id = 5 and
                                    a.action_type = 'ANALYST ACTION' and
                                    a.alert_status = 'ACTIVE' and
                                    trunc(to_date(a.create_timestamp + (l_gmt_offset_hour/24) + (l_gmt_offset_minute/1440) )) = l_snap_date and
                                    s.strategy_type_code = 'OUT'
                                then 1
                                else 0
                            end
                        ) as nas_reRouteCnt
                    from
                        fcm_strategy s,
                        fcm_queue q,
                        fcm_alert_action a
                    where
                        q.strategy_id = s.strategy_id and
                        a.queue_id = q.queue_id and
                        trunc(to_date(a.action_timestamp + (l_gmt_offset_hour/24) + (l_gmt_offset_minute/1440) )) = l_snap_date and
                        s.logical_del_ind = '0' and
                        q.logical_del_ind = '0' and
                        a.action_type in ('ANALYST ACTION','ALERTINIT','INITCLOSED')
                    group by s.business_unit_id, a.multi_org_id, s.strategy_id, q.queue_id, a.alert_type
                )
                select
                -- ------------------------------------------------------------------------------------------------------------------
                -- Columns that cut across all report types
                -- ------------------------------------------------------------------------------------------------------------------
                    l_snap_date as snap_date,
                    l_iteration_nbr as iteration_number,
                    l_current_gmt_timestamp as loader_gmt_timestamp,
                    s.multi_org_id,
                    s.strategy_id,
                    s.queue_id,
                    s.multi_org_name,
                    s.strategy_name,
                    s.queue_name,
                    s.alert_type,
                    s.alert_type_name,
                -- ------------------------------------------------------------------------------------------------------------------
                -- Columns used primarily for Alert-centric Fraud Summary report
                -- ------------------------------------------------------------------------------------------------------------------
                    coalesce(serviceableAlertsCnt,0) - coalesce(serviceableUnschedReviewed,0) + coalesce(Scheduled_type_ii, 0) + coalesce(unscheduled_type_ii,0) + coalesce(Unscheduled_types_i_and_iii,0) as total_alert_count,
                    case
                        when s.strategy_type_code = 'OUT'
                            then coalesce(serviceableAlertsCnt,0) - coalesce(serviceableUnschedReviewed,0) + coalesce(Scheduled_type_ii, 0)
                        else 0
                    end as scheduled_alert_count,
                    case
                        when s.strategy_type_code = 'OUT' and coalesce(serviceableAlertsCnt,0) - coalesce(serviceableUnschedReviewed,0) + coalesce(Scheduled_type_ii, 0)>= coalesce(newAlertsCnt,0)
                            then coalesce(serviceableAlertsCnt,0) - coalesce(serviceableUnschedReviewed,0) + coalesce(Scheduled_type_ii, 0)- coalesce(newAlertsCnt,0)
                        else 0
                    end as ac_carryover_alert_count,
                    coalesce(newAlertsCnt,0)   as new_alert_count,
                    coalesce(Unscheduled_types_i_and_iii,0) + coalesce(unscheduled_type_ii,0) as unschd_alert_count,
                    coalesce(actioned,0)      as actioned_alert_count,
                    coalesce(Scheduled_type_ii, 0) + coalesce(serviceableReviewed,0) as schd_actioned_alert_count,
                    case
                        when s.strategy_type_code = 'OUT' and coalesce(serviceableAlertsCnt,0) - coalesce(serviceableUnschedReviewed,0) + coalesce(Scheduled_type_ii, 0)> 0.001
                            then
                                coalesce(cast( ( coalesce(Scheduled_type_ii, 0) + coalesce(serviceableReviewed,0) )  as decimal(19,5) )/ cast (coalesce(serviceableAlertsCnt,0) - coalesce(serviceableUnschedReviewed,0) + coalesce(Scheduled_type_ii, 0) as decimal (19,5) ),0.00)
                        else 0.00
                    end as alert_penetration_rate,
                    coalesce(Unscheduled_types_i_and_iii,0) + coalesce(unscheduled_type_ii,0) as unschd_actioned_alert_count,
                    coalesce(connectCnt,0)    as analyst_action_count,
                    coalesce(verifiedActivity,0) + coalesce(confirmedFraud,0) as resolved_alert_count,
                    case
                        when coalesce(actioned,0) > 0.001
                            then
                                cast(coalesce(verifiedActivity,0) + coalesce(confirmedFraud,0) as decimal(19,5)) / actioned
                        else 0
                    end  as resolved_alert_rate,
                    coalesce(skipCnt,0)    as skip_count,
                    coalesce(reRouteCnt,0)    as reroute_count,
                    coalesce(rescheduleCnt,0)    as reschd_count,
                    coalesce(pendCnt,0)    as pend_count,
                    coalesce(pendBlockCnt,0)    as pend_block_count,
                    coalesce(verifiedActivity,0)    as verified_ok_count,
                    coalesce(confirmedFraud,0)            as confirmed_fraud_count,
                    case
                        when coalesce(confirmedFraud,0) > 0.001
                            then
                                cast(coalesce(verifiedActivity,0) as decimal(19,5)) / confirmedFraud
                        else 0
                    end as fp_ratio,
                    coalesce(prevented,0.00)    as saved_amount,
                    coalesce(totalTimeSec,0.00)    as total_seconds_worked,
                -- ------------------------------------------------------------------------------------------------------------------
                -- Fraud type counts and Verified Activity counts for Fraud Queue False Positive report broken out over
                --   service method code types.
                -- ------------------------------------------------------------------------------------------------------------------
                    coalesce(fqfp_verifiedActivity_out_cnt, 0) as fqfp_verifiedActivity_out_cnt,
                    coalesce(fqfp_verifiedActivity_inb_cnt, 0) as fqfp_verifiedActivity_inb_cnt,
                    coalesce(fqfp_confirmedFraud_out_cnt, 0) as fqfp_confirmedFraud_out_cnt,
                    coalesce(fqfp_confirmedFraud_inb_cnt, 0) as fqfp_confirmedFraud_inb_cnt,

                -- ------------------------------------------------------------------------------------------------------------------
                -- Outbound service mode false positive ratio metrics for Fraud Queue False Positive report
                -- ------------------------------------------------------------------------------------------------------------------
                    case
                        when coalesce(fqfp_confirmedFraud_out_cnt,0) > 0.001
                            then
                                cast(coalesce(fqfp_verifiedActivity_out_cnt,0) as decimal(19,5)) / cast(fqfp_confirmedFraud_out_cnt as decimal(19,5))
                        else 0
                    end as fqfp_out_fpRatio,

                -- ------------------------------------------------------------------------------------------------------------------
                -- Inbound service mode false positive ratio metrics for Fraud Queue False Positive report
                -- ------------------------------------------------------------------------------------------------------------------
                    case
                        when coalesce(fqfp_confirmedFraud_inb_cnt,0) > 0.001
                            then
                                cast(coalesce(fqfp_verifiedActivity_inb_cnt,0) as decimal(19,5)) / fqfp_confirmedFraud_inb_cnt
                        else 0
                    end as fqfp_inb_fpRatio,

                -- ------------------------------------------------------------------------------------------------------------------
                -- Columns used for New Alerts Scheduled report
                -- ------------------------------------------------------------------------------------------------------------------
                    coalesce(nas_analystActionCount, 0) as nas_analyst_action_count,
                    coalesce(nas_totalTimeSec, 0) as nas_total_seconds_worked,
                    coalesce(nas_skipCnt, 0) as nas_skip_count,
                    coalesce(nas_rescheduleCnt, 0) as nas_reschd_count,
                    coalesce(nas_reRouteCnt, 0) as nas_reroute_count,
                    coalesce(nas_pendCnt, 0) as nas_pend_count,
                    coalesce(nas_pendBlockCnt, 0) as nas_pend_block_count,
                    coalesce(nas_verifiedActivity, 0) as nas_verified_ok_count,
                    coalesce(nas_confirmedFraud, 0) as nas_confirmed_fraud_count,
                    coalesce(nas_verifiedActivity,0) + coalesce(nas_confirmedFraud,0) as nas_resolved_alert_count,
                    coalesce(nas_actioned,0) as nas_actioned_alert_count,
                    case
                        when coalesce(nas_actioned,0) > 0.001
                            then
                                cast(coalesce(nas_verifiedActivity,0) + coalesce(nas_confirmedFraud,0) as decimal(19,5)) / nas_actioned
                        else 0
                    end  as nas_resolved_alert_rate,
                    coalesce(nas_prevented, 0) as nas_saved_amount,
                    case
                        when coalesce(nas_confirmedFraud,0) > 0.001
                            then
                                cast(coalesce(nas_verifiedActivity,0) as decimal(19,5)) / nas_confirmedFraud
                        else 0
                    end as nas_fp_ratio,
                    case
                        when s.strategy_type_code = 'OUT' and coalesce(nas_serviceableAlertsCnt,0) + coalesce(nas_Scheduled_type_ii, 0)> 0.001
                            then
                                coalesce(cast( ( coalesce(nas_Scheduled_type_ii, 0) + coalesce(nas_serviceableReviewed,0) )  as decimal(19,5) )/ cast (coalesce(nas_serviceableAlertsCnt,0) + coalesce(nas_Scheduled_type_ii, 0) as decimal (19,5) ),0.00)
                        else 0.00
                    end as nas_penetration_rate
                from
                    (select distinct
                        a.multi_org_id,
                        m.multi_org_name,
                        st.strategy_id,
                        st.strategy_name,
                        st.strategy_type_code,
                        q.queue_id,
                        q.queue_name,
                        a.alert_type,
                        at.alert_type_name
                    from
                        fcm_strategy st,
                        fcm_queue q,
                        fcm_alert a,
                        fcm_multi_org m,
                        fcm_alert_type at
                    where
                        st.strategy_id = q.strategy_id
                        and q.queue_id = a.queue_id
                        and a.multi_org_id = m.multi_org_id
                        and a.alert_type = at.alert_type
                        and m.logical_del_ind = '0'
                        and st.logical_del_ind = '0'
                        and q.logical_del_ind = '0'
                        and a.logical_del_ind = '0'
                        and at.logical_del_ind = '0') s
                    left outer join SchedAndUnschedTypes lots on lots.multi_org_id = s.multi_org_id
                                    and lots.strategy_id = s.strategy_id and lots.queue_id = s.queue_id and lots.alert_type = s.alert_type
                    left outer join serviceableAlerts svc on svc.multi_org_id = s.multi_org_id
                                    and svc.strategy_id = s.strategy_id and svc.queue_id = s.queue_id and svc.alert_type = s.alert_type
                    left outer join unresolvedActions ur on ur.multi_org_id = s.multi_org_id
                                    and ur.strategy_id = s.strategy_id and ur.queue_id = s.queue_id and ur.alert_type = s.alert_type
                ;

            COMMIT;

-- S0553598 LEUSHE
--      END IF;

         l_snap_date := ( l_snap_date +  1 ) ;
         l_iteration_nbr := 0;
         l_current_gmt_timestamp := SYS_EXTRACT_UTC(CURRENT_TIMESTAMP);

    END LOOP;
--
--

END daily_rpt_snapshot ;
/
show errors;